@@ -592,6 +592,10 @@ typedef struct {
     char *keyboard;
     char *mouse;
     char *keyboard_driver;
+
+    int supports_extension_section;
+    int autoloads_glx;
+
 } GenerateOptions;
 
 
@@ -725,6 +729,10 @@ void xconfigGenerateAssignScreenAdjacencies(XConfigLayoutPtr layout);
 
 void xconfigGeneratePrintPossibleMice(void);
 void xconfigGeneratePrintPossibleKeyboards(void);
+void xconfigGenerateLoadDefaultOptions(GenerateOptions *gop);
+
+void xconfigGetXServerInUse(GenerateOptions *gop);
+
 
 /*
  * check (and update, if necessary) the inputs in the specified layout
